@@ -4,6 +4,7 @@ A collection of reference ISP algorithms.
 
 import time                  # built-in library
 import warnings              # built-in library
+from typing import Type      # built-in library
 from typing import Tuple     # built-in library
 from typing import Sized     # built-in library
 from typing import Iterable  # built-in library
@@ -47,7 +48,6 @@ class Algorithms:
         """
         Split the given Bayer frame into four single-color frames.
         """
-        # pylint: disable=no-self-use
         ch1 = frame[0::2, 0::2]
         ch2 = frame[0::2, 1::2]
         ch3 = frame[1::2, 0::2]
@@ -62,7 +62,6 @@ class Algorithms:
         """
         Interleave the given Bayer channels into a complete frame.
         """
-        # pylint: disable=no-self-use
         frame = np.zeros(np.array(ch1.shape) * 2, dtype=ch1.dtype)
         frame[0::2, 0::2] = ch1
         frame[0::2, 1::2] = ch2
@@ -189,7 +188,7 @@ class Algorithms:
                             "GBRG": cv2.COLOR_BAYER_GR2RGB_EA,
                             "BGGR": cv2.COLOR_BAYER_RG2RGB_EA,
                             "GRBG": cv2.COLOR_BAYER_GB2RGB_EA}
-            frame = (frame * 65535).astype(np.uint16)
+            frame = np.rint(frame * 65535).astype(np.uint16)
             frame = cv2.cvtColor(frame, bayer_to_cv2[bayer_pattern.upper()])
             frame = frame / 65535.0
             method = "EAD"
@@ -372,12 +371,14 @@ class Algorithms:
                 lut = np.linspace(0, 1, 2 ** bpp)
                 mode = "LUT"
                 if realmode == "sRGB":
+                    assert lut is not None
                     srgb_lo = 12.92 * lut
-                    srgb_hi = 1.055 * np.power(lut, 1.0/2.4) - 0.055
+                    srgb_hi = 1.055 * np.power(lut, 1.0 / 2.4) - 0.055
                     threshold_mask = (lut > 0.0031308)
                     lut = srgb_hi * threshold_mask + srgb_lo * (~threshold_mask)
                     lut = lut * maxval
                 if realmode == "rec709":
+                    assert lut is not None
                     srgb_lo = 4.5 * lut
                     srgb_hi = 1.099 * np.power(lut, 0.45) - 0.099
                     threshold_mask = (lut > 0.018)
@@ -395,7 +396,7 @@ class Algorithms:
     def quantize(self,
                  frame: np.ndarray,
                  maxval: int = 65535,
-                 dtype: np.dtype = np.uint16) -> np.ndarray:
+                 dtype: Type = np.uint16) -> np.ndarray:
         """
         Clip the given frame to [0, 1], rescale it to [0, maxval], and convert
         it to the given dtype with proper rounding. This algorithm is format-
@@ -424,7 +425,7 @@ class Algorithms:
         frame = self.quantize(frame, maxval=65535, dtype=np.uint16)
         return frame
 
-    def _quantize(self, frame: np.ndarray, maxval: int = 65535, dtype: np.dtype = np.uint16) -> np.ndarray:
+    def _quantize(self, frame: np.ndarray, maxval: int = 65535, dtype: Type = np.uint16) -> np.ndarray:
         """
         Forced silent version of quantize().
         """
@@ -469,12 +470,12 @@ def _transform_hsl_to_srgb(frame: np.ndarray) -> np.ndarray:
     return rgb
 
 
-def _aces_gamut(rgb, threshold=[0.815, 0.803, 0.880], cyan=0.147, magenta=0.264, yellow=0.312, power=1.2):
+def _aces_gamut(rgb, threshold=np.array([0.815, 0.803, 0.880]), cyan=0.147, magenta=0.264, yellow=0.312, power=1.2):
 
     def compress(dist, lim, thr, power):
         # power(p) compression function plot https://www.desmos.com/calculator/54aytu7hek
         invp = 1 / power
-        s = (lim - thr) / ((((1 - thr) / (lim - thr)) ** -power) - 1) ** invp # calc y=1 intersect
+        s = (lim - thr) / ((((1 - thr) / (lim - thr)) ** -power) - 1) ** invp  # calc y=1 intersect
         with np.errstate(invalid="ignore"):
             cdist = thr + (dist - thr) / (1 + ((dist - thr) / s) ** power) ** invp  # compress
             cdist = np.nan_to_num(cdist)  # result for dist <= thr will be NaN
